==> ejc-proother-impl-3.0.0-20220329.124042-20-sources.jar: com/ejianc/business/proother/bean/RecordClauseEntity.java <==
package com.ejianc.business.proother.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 分包记录条款实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proother_contract_record_clause")
public class RecordClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    @TableField("clause_name_id")
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    @TableField("clause_name")
    private String clauseName;

    /**
     * 合同条款内容
     */
    @TableField("clause_content")
    private String clauseContent;

    /**
     * 所属合同Id
     */
    @TableField("contract_id")
    private Long contractId;

    /**
     * 变更主键
     */
    @TableField("change_id")
    private Long changeId;

    /**
     * 变更子表主键
     */
    @TableField("change_bid")
    private Long changeBid;

    /**
     * 记录表ID
     */
    @TableField("record_id")
    private Long recordId;

    /**
     * 来源主合同子表id
     */
    @TableField("src_table_id")
    private Long srcTableId;

    public Long getSrcTableId() {
        return srcTableId;
    }

    public void setSrcTableId(Long srcTableId) {
        this.srcTableId = srcTableId;
    }

    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
}

==> ejc-proother-impl-3.0.0-20220429.084434-40-sources.jar: com/ejianc/business/proother/bean/RecordClauseEntity.java <==
package com.ejianc.business.proother.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 分包记录条款实体
 * 
 * @author generator
 * 
 */
 @TableName("ejc_proother_contract_record_clause")
public class RecordClauseEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    /**
     * 合同条款名称Id
     */
    @TableField("clause_name_id")
    private Long clauseNameId;

    /**
     * 合同条款名称
     */
    @TableField("clause_name")
    private String clauseName;

    /**
     * 合同条款内容
     */
    @TableField("clause_content")
    private String clauseContent;

    /**
     * 是否必填：1-是，0否
     */
    @TableField("necessary_status")
    private Integer necessaryStatus;

    /**
     * 所属合同Id
     */
    @TableField("contract_id")
    private Long contractId;

    /**
     * 变更主键
     */
    @TableField("change_id")
    private Long changeId;

    /**
     * 变更子表主键
     */
    @TableField("change_bid")
    private Long changeBid;

    /**
     * 记录表ID
     */
    @TableField("record_id")
    private Long recordId;

    /**
     * 来源主合同子表id
     */
    @TableField("src_table_id")
    private Long srcTableId;

    public Integer getNecessaryStatus() {
        return necessaryStatus;
    }

    public void setNecessaryStatus(Integer necessaryStatus) {
        this.necessaryStatus = necessaryStatus;
    }

    public Long getSrcTableId() {
        return srcTableId;
    }

    public void setSrcTableId(Long srcTableId) {
        this.srcTableId = srcTableId;
    }

    public Long getClauseNameId() {
        return clauseNameId;
    }

    public void setClauseNameId(Long clauseNameId) {
        this.clauseNameId = clauseNameId;
    }

    public String getClauseName() {
        return clauseName;
    }

    public void setClauseName(String clauseName) {
        this.clauseName = clauseName;
    }

    public String getClauseContent() {
        return clauseContent;
    }

    public void setClauseContent(String clauseContent) {
        this.clauseContent = clauseContent;
    }

    public Long getContractId() {
        return contractId;
    }

    public void setContractId(Long contractId) {
        this.contractId = contractId;
    }

    public Long getChangeId() {
        return changeId;
    }

    public void setChangeId(Long changeId) {
        this.changeId = changeId;
    }

    public Long getChangeBid() {
        return changeBid;
    }

    public void setChangeBid(Long changeBid) {
        this.changeBid = changeBid;
    }

    public Long getRecordId() {
        return recordId;
    }

    public void setRecordId(Long recordId) {
        this.recordId = recordId;
    }
}
